###################################################
#   y ^
#   --|--------------------------|------> x
#    O|\_                      _/  L
#     |  \_                   /
#     |    \_                /
#     |      |              |
#     |       \            /
#     |        \          /
#     |        |          |
#     |         \_      _/
#     |           \____/
#     |
#
###################################################
reset;
param N := 100;	# number of anelli/segmenti di cui è composta la catena
param L := 1;	# lunghezza della catena (in unità di misura)

param h := 2*L/N;	# lunghezza di ogni anello/segmento
param m := 1;		# ogni anello ha massa unitaria
param g := 9.81;	# accellerazione di gravità

var x {0..N} >= 0, <= L;	# x-coord degli anelli
var y {0..N};				    # y-coord degli anelli

minimize pot_energy: sum{j in 1..N} m*g*(y[j-1] + y[j])/2;

subject to x_left:  x[0] = 0;
subject to y_left:  y[0] = 0;
subject to x_right: x[N] = L;
subject to y_right: y[N] = 0;

subject to link_up {j in 1..N}: N*(x[j] - x[j-1])^2 + (y[j] - y[j-1])^2 <= h^2*N;

let {j in 0..N} x[j] := j*L/N;
let {j in 0..N} y[j] := 0;

option solver minos;
option minos_options 'superbasics=100 major_iterations=10000';

solve;

printf {j in 0..N}: "%10.5f %10.5f \n", x[j], y[j] > xy.out;
printf {j in 0..N}: "\t%10.5f\t%10.5f \n", x[j], y[j];

